import { useState } from 'react'
import { Button, Flex, Modal, Radio, Form, Row, Col, Input } from 'antd'
import { useDataFieldQuery } from '@/hooks/useQuery'
import AppProgressSteps from '@/components/AppProgressSteps'

export default function ButtonModal() {
  const { data: fields = [] } = useDataFieldQuery()

  const [open, setOpen] = useState(false)

  const [current, setCurrent] = useState(0)
  const [form] = Form.useForm()
  const initialValues = {
    checked: '',
    rule: '',
  }

  const checked = Form.useWatch('checked', form)

  const [step, setStep] = useState<number>(-1)

  const steps = [
    {
      title: '请选择去标点字段',
      content: (
        <Form.Item name="checked" rules={[{ required: true, message: '请选择去标点字段' }]}>
          <Radio.Group>
            <Row gutter={[10, 10]}>
              {fields.map((item) => (
                <Col span={6} key={item.english_name}>
                  <Radio value={item.name}>{item.name}</Radio>
                </Col>
              ))}
            </Row>
          </Radio.Group>
        </Form.Item>
      ),
    },
    {
      title: '配置处理规则',
      content: (
        <>
          <Form.Item label="数据去标点字段">{checked}</Form.Item>
          <Form.Item label="处理规则" name="rule" rules={[{ required: true, message: '请输入处理规则' }]}>
            <Input />
          </Form.Item>
        </>
      ),
    },
    {
      title: '处理执行',
      content: (
        <>
          <p>数据去标点处理字段：{checked}</p>
          <Flex vertical align="center" style={{ marginTop: '20px' }}>
            <Button type="primary" onClick={() => setStep(1)}>
              开始处理
            </Button>
            <AppProgressSteps
              style={{ margin: '80px' }}
              current={step}
              items={[
                {
                  title: (
                    <>
                      第一步
                      <br />
                      开始
                    </>
                  ),
                },
                {
                  title: (
                    <>
                      第二步
                      <br />
                      数据去标点处理
                    </>
                  ),
                },
                {
                  title: (
                    <>
                      第三步
                      <br />
                      处理结果
                    </>
                  ),
                },
              ]}
            />
          </Flex>
        </>
      ),
    },
  ]

  return (
    <>
      <Button type="primary" onClick={() => setOpen(true)}>
        数据去标点
      </Button>
      <Modal
        title={steps[current].title}
        open={open}
        footer={
          <Flex justify="center" gap={20}>
            {current > 0 && <Button onClick={() => setCurrent(current - 1)}>上一步</Button>}
            {current < steps.length - 1 && (
              <Button type="primary" onClick={() => setCurrent(current + 1)} disabled={!checked}>
                下一步
              </Button>
            )}
            {current === steps.length - 1 && (
              <Button type="primary" onClick={() => setOpen(false)}>
                关闭
              </Button>
            )}
          </Flex>
        }
        destroyOnClose
        width={800}
        onCancel={() => setOpen(false)}>
        <div style={{ minHeight: 300, padding: '20px 0' }}>
          <Form form={form} labelCol={{ span: 5 }} preserve={false} initialValues={initialValues}>
            {steps.map((item, index) => (
              <div key={index} hidden={current !== index} style={{ marginTop: '20px' }}>
                {item.content}
              </div>
            ))}
          </Form>
        </div>
      </Modal>
    </>
  )
}
